/*=================== FILE ABSTRACT ==========================================
 *
 * Synopsis::         Source for GeneClust user interface (GeneClustFrame)
 *
 * File Name::        %M%
 * Version::          %I%
 * Type::             source
 * Date Completed::   %G%
 *
 * Environment::
 *     Language::     Java
 *     Computer::     Compaq/Alpha
 *     OS::           DigitalUNIX
 *     OSVersion::    4.0
 *
 * Module Information::
 *     Owner::        MDACC
 *     Department::   Biostatistics
 *     Researcher::   Kim-Anh Do
 *     Application::  GeneClust
 *
 *============================================================================*/

/*
 * @(#)GeneClustFrame.java    0.95 2002/03/15
 *
 * Copyright (c) 2002 M.D. Anderson Cancer Center
 * 1515 Holcombe, Houston, TX, 77030, U.S.A.
 * All rights reserved.
 */

package org.mdanderson.biostat.geneclust;

import java.awt.BorderLayout;
import java.awt.Insets;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import javax.swing.JFrame;
import javax.swing.WindowConstants;


/**
 * GeneClustFrame - Implements the user interface frame.
 *
 * @version 0.95 2001/02/20
 * @author <a href="mailto:roebuck@mdanderson.org">P. Roebuck</a>
 */
public class GeneClustFrame extends JFrame
{
    // =========================================================================
    // CONSTRUCTOR
    // =========================================================================

    /**
     * Class constructor specifying title
     *
     * @param title  string to be displayed by the Window Manager
     */
    public GeneClustFrame(String title)
    {
        super(title);
        setName("GeneClustFrame");

        geneclustPanel = new GeneClustPanel(this);

        getContentPane().add(geneclustPanel, BorderLayout.CENTER);
        setJMenuBar(geneclustPanel.getMenuBar());

        addWindowListener(new WindowEventHandler());
        setDefaultCloseOperation(WindowConstants.DISPOSE_ON_CLOSE);

        addNotify();

        // Set preferred dimensions
        {
            final int WIDTH  = (int) getPreferredSize().getWidth();
            final int HEIGHT = (int) getPreferredSize().getHeight();

            Insets insets = getInsets();
            int width  = WIDTH  + (insets.left + insets.right);
            int height = HEIGHT + (insets.top + insets.bottom);

            setSize(width, height);
        }
    }

    // =========================================================================
    // PACKAGE INTERFACE
    // =========================================================================

    /**
     * Returns the user interface panel
     *
     * @return  instance of <code>GeneClustPanel</code> object
     */
    GeneClustPanel getUserInterface()
    {
        return geneclustPanel;
    }

    /**
     * Invokes the parent class's termination routine
     *
     * @param reason  error code
     */
    void invokeTerminate(int reason)
    {
        setVisible(false);
        dispose();
        GeneClust.terminate(reason);
    }

    // =========================================================================
    // LISTENERS/ADAPTERS
    // =========================================================================

    /**
     * WindowEventHandler - Responds to window events.
     *
     * @version 0.95 2001/02/27
     * @author <a href="mailto:roebuck@mdanderson.org">P. Roebuck</a>
     */
    class WindowEventHandler extends WindowAdapter
    {
        // =====================================================================
        // IMPLEMENTS WINDOWLISTENER
        // =====================================================================

        /**
         * Invoked when a window is in the process of being closed.
         * Has same effect as user having selected Exit from File menu.
         *
         * @param event  low-level window status event
         */
        public void windowClosing(WindowEvent event)
        {
            invokeTerminate(0);
        }
    }

    // =========================================================================
    // OBJECT ATTRIBUTES
    // =========================================================================

    private GeneClustPanel geneclustPanel;
}

