/*=================== FILE ABSTRACT ==========================================
 *
 * Synopsis::         Source for text component autoselect event handler class
 *
 * File Name::        %M%
 * Version::          %I%
 * Type::             source
 * Date Completed::   %G%
 *
 * Environment::
 *     Language::     Java
 *     Computer::     Compaq/Alpha
 *     OS::           DigitalUNIX
 *     OSVersion::    4.0
 *
 * Module Information::
 *     Owner::        MDACC
 *     Department::   Biostatistics
 *     Researcher::   N/A
 *     Application::  <generic>
 *
 *============================================================================*/

/*
 * @(#)AutoSelectEventHandler.java    1.0 2001/02/27
 *
 * Copyright (c) 2001 M.D. Anderson Cancer Center
 * 1515 Holcombe, Houston, TX, 77030, U.S.A.
 * All rights reserved.
 */

package org.mdanderson.biostat.util;

import java.awt.Component;
import java.awt.event.FocusEvent;
import java.awt.event.FocusListener;
import javax.swing.text.JTextComponent;


/**
 * AutoSelectEventHandler - Responds to focus events.
 *
 * The intent is to autoselect the text in data entry fields so typing
 * overwrites previous text by default, making it easier on the user.
 *
 * @version 1.0 2001/02/27
 * @author <a href="mailto:roebuck@mdanderson.org">P. Roebuck</a>
 */
public class AutoSelectEventHandler
    implements FocusListener
{
    // =====================================================================
    // IMPLEMENTS FOCUSLISTENER
    // =====================================================================

    /**
     * Invoked when component gains the keyboard focus.
     * Selects all the text in this text component.
     *
     * @param event  low-level input focus event
     */
    public void focusGained(FocusEvent event)
    {
        if (event.isTemporary())
            return;

        handleTextSelection(event, FocusEvent.FOCUS_GAINED);
    }

    /**
     * Invoked when component loses the keyboard focus.
     * Deselects the text in this text component.
     *
     * @param event  low-level input focus event
     */
    public void focusLost(FocusEvent event)
    {
        if (event.isTemporary())
            return;

        handleTextSelection(event, FocusEvent.FOCUS_LOST);
    }

    // =====================================================================
    // CLASS INTERFACE (Private)
    // =====================================================================

    /**
     * Handles text selection based on focus event.
     *
     * @param event  low-level input focus event
     * @param id     integer indicating type of event
     */
    private static void handleTextSelection(FocusEvent event, int id)
    {
        Component component = event.getComponent();
        if (component instanceof JTextComponent)
        {
            JTextComponent textComponent = (JTextComponent) component;

            if (id == FocusEvent.FOCUS_GAINED)
                textComponent.selectAll();
            else if (id == FocusEvent.FOCUS_LOST)
                textComponent.select(0, 0);
        }
    }
}

