/*=================== FILE ABSTRACT ==========================================
 *
 * Synopsis::         Source for key filtering adapter
 *
 * File Name::        %M%
 * Version::          %I%
 * Type::             source
 * Date Completed::   %G%
 *
 * Environment::
 *     Language::     Java
 *     Computer::     Compaq/Alpha
 *     OS::           DigitalUNIX
 *     OSVersion::    4.0
 *
 * Module Information::
 *     Owner::        MDACC
 *     Department::   Biostatistics
 *     Researcher::   N/A
 *     Application::  <generic>
 *
 *============================================================================*/

/*
 * @(#)FilterAdapter.java    1.0 2000/12/26
 *
 * Copyright (c) 2000 M.D. Anderson Cancer Center
 * 1515 Holcombe, Houston, TX, 77030, U.S.A.
 * All rights reserved.
 */

package org.mdanderson.biostat.util;

import java.awt.Component;
import java.awt.Toolkit;
import java.awt.event.KeyEvent;
import java.awt.event.KeyListener;


/**
 * FilterAdapter - Implements keyboard filtering.
 *
 * @version 1.0 2000/12/26
 * @author <a href="mailto:roebuck@mdanderson.org">P. Roebuck</a>
 */
public abstract class FilterAdapter
    implements KeyListener
{
    // =========================================================================
    // CONSTRUCTORS
    // =========================================================================

    /**
     * Class constructor specifying component
     *
     * @param component  component which would receive the keystrokes 
     */
    public FilterAdapter(Component component)
    {
        component.addKeyListener(this);
    }

    // =========================================================================
    // PUBLIC INTERFACE
    // =========================================================================

    /**
     * Enable audio feedback
     */
    public void enableAudio()
    {
        audio = true;
    }

    /**
     * Disable audio feedback
     */
    public void disableAudio()
    {
        audio = false;
    }

    /**
     * Determines if the key is valid in this context
     *
     * @param event  low-level event generated by a component when a key is
     *               pressed, released, or typed
     * @return       true if key is valid for this filter; otherwise, false
     */
    public abstract boolean isKeyValid(KeyEvent event);

    // =========================================================================
    // IMPLEMENTS KEYLISTENER
    // =========================================================================

    /**
     * Invoked when a key has been typed. Filters invalid keystrokes.
     *
     * @param event  keyboard event
     */
    public void keyTyped(KeyEvent event)
    {
        // Ignore action keys
        if (event.isActionKey())
            return;

        if (isKeyValid(event))
            return;

        // Filter this keystroke
        event.consume();

        if (audio)
            toolkit.beep();
    }

    /**
     * Invoked when a key has been pressed. Unused for key filtering.
     *
     * @param event  keyboard event
     */
    public void keyPressed(KeyEvent event)
    {
        return;
    }

    /**
     * Invoked when a key has been released. Unused for key filtering.
     *
     * @param event  keyboard event
     */
    public void keyReleased(KeyEvent event)
    {
        return;
    }

    // =========================================================================
    // CLASS ATTRIBUTES
    // =========================================================================

    static Toolkit toolkit = Toolkit.getDefaultToolkit();

    // =========================================================================
    // OBJECT ATTRIBUTES
    // =========================================================================

    boolean audio = true;
}

