##################### FILE ABSTRACT ############################################
##
## Synopsis::         Source for Demo Plaid 2 model routines
##
## File Name::        %M%
## Version::          %I%
## Type::             source
## Date Completed::   %G%
##
## Environment::
##     Language::     Splus
##     Computer::     Compaq/Alpha
##     OS::           DigitalUNIX
##     OSVersion::    4.0
##
## Module Information::
##     Owner::        MDACC
##     Department::   Biostatistics
##     Researcher::   Kim-Anh Do
##     Application::  geneclust
##
################################################################################

Plaid2.func<-function(N,p,amplitude)
{
## Creates a plaid type matrix with 3 non overlapping clusters
## and overlayed Gaussian noise

    # Check matrix size constraints
    minN<-30;
    minp<-30;
    if (is.numeric(N) && N < minN)
        stop(paste("#rows =",N,", min =",minN,"\n"));
    if (is.numeric(p) && p < minp)
        stop(paste("#columns =",p,", min =",minp,"\n"));

    # Amplitude of the clusters
    a<-c(rep(amplitude,3));
    # Size of each cluster in "genes"(rows)
    n<-c(as.integer(N/3),as.integer(N/2),as.integer(N/3));
    # Size of each cluster in "cells"(cols)
    r<-c(as.integer(p/2),as.integer(p/2),as.integer(p/3));
    # Beginning row of each cluster
    nb<-c(1,as.integer(N/5),as.integer(N-N/3));
    rb<-c(1,as.integer(p/3),as.integer(p-p/3));

    X<-matrix(0,nrow=N,ncol=p);
    Y<-matrix(0,nrow=N,ncol=p);
    Z<-matrix(0,nrow=N,ncol=p);

    X[nb[1]:(nb[1]+n[1]),1:r[1]]<-a[1]
    Y[nb[2]:(nb[2]+n[2]),rb[2]:(rb[2]+r[2])]<-a[2]
    Z[nb[3]:(nb[3]+n[3]),rb[3]:(rb[3]+r[3])]<-a[3]
    W<-X+Y+Z;

    return(W);
}

GCDemoPlaid2.func<-function(nclst,percentToShave,nperm,gapTolerance,N,p,a,
                            noise,df,percentSupervision,classificationFileName)
{
    cat("PK_MONITOR_CREATE_MATRIX\n");

    X<-Plaid2.func(N,p,a);
    Data<-Common.func(X,
                      N,
                      p,
                      nclst,
                      percentToShave,
                      nperm,
                      gapTolerance,
                      noise,
                      df,
                      percentSupervision,
                      classificationFileName);

    return(Data);
}

