
##******************************************************************************
CheckNoise.func<-function(X,noise,df)
{
    N<-dim(X)[1];
    p<-dim(X)[2];

    if (noise == 0) {
        ## No noise
        Z<-X;
        Y<-c(rep(0,N*p));
    }
    else if (noise == 1) {
        ## Generate Gaussian noise
        v<-rnorm(N*p, mean=0, sd=1)
        Y<-matrix(v,N,ncol=p);
        Z<-X + Y;
    }
    else if (noise == 2) {
        ## Generate Chi-square noise
        v<-rchisq(N*p,df);
        Y<-matrix(v,N,ncol=p);
        Z<-X + Y;
    }
    else if (noise == 3) {
        ## Generate t noise (Student's distribution)
        v<-rt(N*p,df);
        Y<-matrix(v,N,ncol=p);
        Z<-X + Y;
    }

    return(list(Z=Z,Y=Y));
}


##******************************************************************************
## Calculates the rms value of Signal To Noise Ratio according to
## "Digital Image Processing" by Rafael Gonzalez and Paul Wintz
## Overlays noise on top of X
## Calls GeneShave and displays hierarchical clustering results,
## the gene Expression matrix, clusters and gap and variance graphs
##******************************************************************************
Common.func<-function(X,N,p,nclst,percentToShave,nperm,gapTolerance,noise,df,
                      percentSupervision, clsFilename)
{
    MyData<-CheckNoise.func(X,noise,df);
    GeneExpression<-MyData$Z;
    Noise<-MyData$Y;
    A<-as.vector(matrix(t(X),N*p,1));
    tempA<-A*A;
    ResSumSignal<-sum(tempA);
    B<-as.vector(matrix(t(Noise),N*p,1));
    tempB<-B*B;
    ResSumNoise<-sum(tempB);

    if (noise == 0)
        SNR<- -1.0
    else
        SNR<-ResSumSignal/ResSumNoise;

    flag<-is.matrix(GeneExpression);

    V<-as.vector(matrix(t(GeneExpression),N*p,1));
    is.vector(V);

    verbose<-TRUE;
    generateLabels<-TRUE;

    data <- list(C=GeneExpression, N=N, p=p);
    SaveData.func(data);

    if (is.null(clsFilename) != TRUE)
        classFileName<-GetAbsPathName.func(clsFilename)
    else
        classFileName<-NULL;

    nclstFound<-0;
    nclstAct<-GeneShave.C(GCoutput,nclst,
                          percentToShave,
                          nperm,
                          gapTolerance,
                          V,
                          N,
                          p,
                          verbose,
                          generateLabels,
                          writeMatrix,
                          percentSupervision,
                          classFileName,
                          nclstFound);

    cat("PK_MONITOR_APP_PROCESSING_COMPLETE\n");

    return();
}

junkStorage <- function()
{
    ## calculate SNR
    ## display the original matrix
    matrixgraph<-ShowMatrix.func(GeneExpression,N,p);
    sqrtSNR<-sqrt(SNR);
    if (noise == 0)
        maintitle<-"Gene Expression Matrix, SNR= infinity"
    else
        maintitle<-paste("Gene Expression Matrix, SNR=\t",round(sqrtSNR,4));

    subtitle<-paste("# Genes =",N,"# cell-lines=",p);
    title(main=maintitle,sub=subtitle);
    outfile<-paste(GCoutput,"GCmatrix.ps",sep="/");
    if (GCinterpreter == "R") {
    }
    else {
        printgraph(horizontal=TRUE,print=FALSE,file=outfile);
    }

    ## perform hierarchical clustering, if requested
    DisplayHclust.func(GeneExpression);

    ## update user interface
    cat("PK_MONITOR_DISPLAY_RESULTS\n");

    ## display clusters
    ShowClusters.func(N,p,2);

    ## display gap
    ShowGap.func();

    ## display variance
    ShowVariance.func();

    ## display principal component
    ShowPC.func();

}
