/*=================== FILE ABSTRACT ==========================================
 *
 * Synopsis::         Public header for the functions used in the
 *                    command line version of the code
 *
 *
 * File Name::        %M%
 * Version::          %I%
 * Type::             include
 * Date Completed::   %G%
 *
 * Environment::
 *     Language::     ANSI C
 *     Computer::     Compaq/Alpha
 *     OS::           DigitalUNIX
 *     OSVersion::    4.0
 *
 * Module Information::
 *     Owner::        MDACC
 *     Department::   Biostatistics
 *     Researcher::   Kim-Anh Do
 *     Application::  geneclust
 *
 *============================================================================*/
/* %W% %G% %U% */

#ifndef UTILITY_H
#define UTILITY_H	1

#include <stdio.h>
#include <gsl/gsl_vector.h>
#include <gsl/gsl_matrix.h>
#include "cplusplus.h"


BEGIN_EXTERN_C

/*
 * Defines
 */
#define CVECTOR_ELEM_LEN	79

/* Short type names.
 */
#define	matrix_t	gsl_matrix
#define vector_t	gsl_vector
#define ivector_t	gsl_vector_int

/*
 * Function Declarations
 */
extern void CenterData (matrix_t *, int, int);
extern void DataDump (matrix_t *, int, int, const ivector_t *, const char *);
extern void InitMatrix (matrix_t *, int, int);
extern void InitVector (vector_t *, int);
extern void StoreMatrixAsRowMajor (matrix_t *, double *, int, int);
extern void StoreMatrixAsColMajor (matrix_t *, double *, int, int);
extern void FetchMatrixAsRowMajor (double *, matrix_t *, int, int);
extern void FetchMatrixAsColMajor (double *, matrix_t *, int, int);

extern gsl_matrix * dmatrix (int rl, int rh, int cl, int ch);
extern void free_dmatrix (gsl_matrix *m, int rl, int rh, int cl, int ch);
extern gsl_vector * dvector (int rl, int rh);
extern void free_dvector (gsl_vector *v, int rl, int rh);
extern gsl_vector_int * ivector (int rl, int rh);
extern void free_ivector (gsl_vector_int *v, int rl, int rh);
extern void choldc (gsl_matrix *a, int n, gsl_vector *p);
extern void svdcmp (gsl_matrix *mat, gsl_matrix *a, int n, int m, gsl_vector *w, gsl_matrix *v);

extern char **cvector (int n);
extern void free_cvector (char **s, int n);
extern void **pvector (int n);
extern void free_pvector (void **v, int n);

#undef TRACEFNS

END_EXTERN_C

#endif /* UTILITY_H */
